local me = CreateFrame("Frame" );

--- Builds a standard tooltip for a control.
function me:ControlOnEnter()
	GameTooltip:SetOwner(self, "ANCHOR_TOPRIGHT" );
	GameTooltip:SetText(self.tooltipText, nil, nil, nil, nil, 1 );
end

--Debug, EPGP show, Breaktime, Threshhold, miniLevel to show gear for

me.okay = function() 
	ElgohDebug=me.Debug:GetChecked();
	ElgohUpdateNote=me.UpdateNote:GetChecked();
	showValues=me.EPGP:GetChecked();
	BreaktimeString=me.Breaktime:GetText();
	miniLevel=tonumber(me.ilvlBox:GetText());
	ElgohMainspec=me.Mainspec:GetText();
	ElgohOffspec=me.Offspec:GetText();
	Elgoh_CreateIgnoreList();
end

me.cancel = function() 
	me.EPGP:SetChecked(showValues);
	me.UpdateNote:SetChecked(ElgohUpdateNote);
	me.Debug:SetChecked(ElgohDebug);
	me.Breaktime:SetText(BreaktimeString);
	me.ilvlBox:SetText(miniLevel);
	me.Offspec:SetText(ElgohOffspec);
	me.Mainspec:SetText(ElgohMainspec);
	me.IgnoredRanks:SetText(Elgoh_FlattenIgnoreList());
end

me.default = function() 
	me.EPGP:SetChecked(true);
	me.UpdateNote:SetChecked(False);
	me.Debug:SetChecked(false);
	me.Breaktime:SetText("Breaktime! Be back in TIME minutes!");
	me.ilvlBox:SetText("359");
	me.Offspec:SetText("Roll for ITEM Offspec");
	me.Mainspec:SetText("Roll for ITEM Mainspec");
	me.IgnoredRanks:SetText("Alts,Social Members,Leader Alts");
end

function Elgoh_CreateIgnoreList()
	ElgohIgnoreList={};
	s=me.IgnoredRanks:GetText();
	s = s..","
	local fieldstart = 1
	repeat
		local nexti = string.find(s, ",", fieldstart)
		ElgohIgnoreList[string.sub(s, fieldstart, nexti-1)]=true;
		fieldstart = nexti + 1
	until fieldstart > string.len(s)
end

function Elgoh_FlattenIgnoreList()
	local returnval="";
	for rank,_ in pairs(ElgohIgnoreList) do
		returnval=returnval..","..rank;
	end
	returnval=string.sub(returnval,2);
	return returnval;
end

function Elgoh_OptionsLoaded()
	me.cancel();
end

me.name = "Elgoh";
me:Hide();

-- Pane title
local Title = me:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge" );
Title:SetPoint( "TOPLEFT", 16, -16 );
Title:SetText("Elgoh");
local SubText = me:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall" );
SubText:SetPoint("TOPLEFT", Title, "BOTTOMLEFT", 0, -8 );
SubText:SetPoint("RIGHT", -32, 0 );
SubText:SetHeight(32);
SubText:SetJustifyH( "LEFT" );
SubText:SetJustifyV( "TOP" );
SubText:SetText("General settings, this part is a work in progress so more settings will be added with each update");

-- Miscellaneous checkboxes
me.Debug = CreateFrame("CheckButton", "ElgohDebugCheckbox", me, "InterfaceOptionsCheckButtonTemplate");
me.Debug:SetPoint( "TOPLEFT", SubText, "BOTTOMLEFT", -2, -8 );
getglobal(me.Debug:GetName() .. "Text"):SetText("Enable Debug Mode");
me.Debug.tooltipText = "Enables Debug Mode";

me.UpdateNote = CreateFrame("CheckButton", "ElgohUpdateNoteCheckbox", me, "InterfaceOptionsCheckButtonTemplate");
me.UpdateNote:SetPoint( "LEFT", me.Debug, "RIGHT", 150, 0 );
getglobal(me.UpdateNote:GetName() .. "Text"):SetText("Enable Update Notifications");
me.UpdateNote.tooltipText = "Warns when a member has been updated";

me.EPGP = CreateFrame("CheckButton", "ElgohEPGPCheckbox", me, "InterfaceOptionsCheckButtonTemplate");
me.EPGP:SetPoint( "TOPLEFT", me.Debug, "BOTTOMLEFT", -0, -8 );
getglobal(me.EPGP:GetName() .. "Text"):SetText("Toggle EPGP Values");
me.EPGP.tooltipText = "Toggles showing of EPGP values in item tooltips";


-- Breaktime
local BreakLabel = me:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
BreakLabel:SetPoint( "TOPLEFT", me.EPGP, "BOTTOMLEFT", -0, -10 );
BreakLabel:SetText("Text to post during /breaktime");

me.Breaktime = CreateFrame("EditBox", "ElgohBreaktimeBox", me, "InputBoxTemplate")
me.Breaktime:SetWidth(400)
me.Breaktime:SetHeight(20)
me.Breaktime:SetPoint("TOP", BreakLabel, "TOP", 0,2);
me.Breaktime:SetPoint("LEFT", BreakLabel, "RIGHT", 15,0);
me.Breaktime:SetAutoFocus(false)
me.Breaktime:SetScript("OnEnterPressed", function() me.Breaktime:ClearFocus(); end)
me.Breaktime.tooltipText="\"TIME\" will be replaced with the time in minutes";
me.Breaktime:SetScript( "OnEnter", me.ControlOnEnter);
me.Breaktime:SetScript( "OnLeave", GameTooltip_Hide);

-- Mainspec
local MainspecLabel = me:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
MainspecLabel:SetPoint( "TOPLEFT", BreakLabel, "BOTTOMLEFT", -0, -30 );
MainspecLabel:SetText("What to post for Mainspec Rolls");

me.Mainspec = CreateFrame("EditBox", "ElgohMainspecBox", me, "InputBoxTemplate")
me.Mainspec:SetWidth(400)
me.Mainspec:SetHeight(20)
me.Mainspec:SetPoint("TOP", MainspecLabel, "TOP", 0,2);
me.Mainspec:SetPoint("LEFT", me.Breaktime, "LEFT", 0,0);
me.Mainspec:SetAutoFocus(false)
me.Mainspec:SetScript("OnEnterPressed", function() me.Mainspec:ClearFocus(); end)
me.Mainspec.tooltipText="\"ITEM\" will be replace with the item link";
me.Mainspec:SetScript( "OnEnter", me.ControlOnEnter);
me.Mainspec:SetScript( "OnLeave", GameTooltip_Hide);

-- Offspec
local OffspecLabel = me:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
OffspecLabel:SetPoint( "TOPLEFT", MainspecLabel, "BOTTOMLEFT", -0, -10 );
OffspecLabel:SetText("What to post for Offspec Rolls");

me.Offspec = CreateFrame("EditBox", "ElgohOffspecBox", me, "InputBoxTemplate")
me.Offspec:SetWidth(400)
me.Offspec:SetHeight(20)
me.Offspec:SetPoint("TOP", OffspecLabel, "TOP", 0,2);
me.Offspec:SetPoint("LEFT", me.Breaktime, "LEFT", 0,0);
me.Offspec:SetAutoFocus(false)
me.Offspec:SetScript("OnEnterPressed", function() me.Offspec:ClearFocus(); end)
me.Offspec.tooltipText="\"ITEM\" will be replace with the item link";
me.Offspec:SetScript( "OnEnter", me.ControlOnEnter);
me.Offspec:SetScript( "OnLeave", GameTooltip_Hide);

-- IgnoredRanks
local IgnoredRanksLabel = me:CreateFontString( nil, "ARTWORK", "GameFontHighlight" );
IgnoredRanksLabel:SetPoint( "TOPLEFT", OffspecLabel, "BOTTOMLEFT", -0, -30 );
IgnoredRanksLabel:SetText("Ranks to ignore from stuff");

me.IgnoredRanks = CreateFrame("EditBox", "ElgohIgnoredRanksBox", me, "InputBoxTemplate")
me.IgnoredRanks:SetWidth(400)
me.IgnoredRanks:SetHeight(20)
me.IgnoredRanks:SetPoint("TOP", IgnoredRanksLabel, "TOP", 0,2);
me.IgnoredRanks:SetPoint("LEFT", me.Breaktime, "LEFT", 0,0);
me.IgnoredRanks:SetAutoFocus(false)
me.IgnoredRanks:SetScript("OnEnterPressed", function() me.IgnoredRanks:ClearFocus(); end)
me.IgnoredRanks.tooltipText="A comma-separated list of ranks to be ignored from reports and start bonus";
me.IgnoredRanks:SetScript( "OnEnter", me.ControlOnEnter);
me.IgnoredRanks:SetScript( "OnLeave", GameTooltip_Hide);

--ItemLevel
me.ilvlBox = CreateFrame("EditBox", "ElgohilvlBox", me, "InputBoxTemplate")
me.ilvlBox:SetWidth(60)
me.ilvlBox:SetHeight(20)
me.ilvlBox:SetPoint("TOP", me.EPGP, "TOP", 0,0);
me.ilvlBox:SetPoint("LEFT", me.Breaktime, "LEFT", 0,0);
me.ilvlBox:SetAutoFocus(false)
me.ilvlBox:SetJustifyH("CENTER");
me.ilvlBox:SetScript("OnEnterPressed", function() me.ilvlBox:ClearFocus(); end)
me.ilvlBox.tooltipText="The minimum Item Level to display EPGP values for";
me.ilvlBox:SetScript( "OnEnter", me.ControlOnEnter );
me.ilvlBox:SetScript( "OnLeave", GameTooltip_Hide );

--Misc Tooltips
btnReport.tooltipText="Click for an online report, Shift click for a full report";
btnReport:SetScript("OnEnter", me.ControlOnEnter); 
btnReport:SetScript("OnLeave", GameTooltip_Hide);

btnOVoteT.tooltipText="Click to toggle the vote frame";
btnOVoteT:SetScript("OnEnter", me.ControlOnEnter); 
btnOVoteT:SetScript("OnLeave", GameTooltip_Hide);

btnStartDKP.tooltipText="Click to generate a list of people for Start Bonus, shift click to print a list";
btnStartDKP:SetScript("OnEnter", me.ControlOnEnter); 
btnStartDKP:SetScript("OnLeave", GameTooltip_Hide);

edtPTarget.tooltipText="Type text here then press enter to have your current target say it in guild/party/raid (requires elgoh)";
edtPTarget:SetScript("OnEnter", me.ControlOnEnter); 
edtPTarget:SetScript("OnLeave", GameTooltip_Hide);

InterfaceOptions_AddCategory(me);

		
-- Elgoh.childpanel = CreateFrame( "Frame", "ElgohChild", Elgoh.panel);
-- Elgoh.childpanel.name = "MyChild";
-- Elgoh.childpanel.parent = Elgoh.panel.name;
-- InterfaceOptions_AddCategory(Elgoh.childpanel)